from setuptools import setup

setup(name='findex_common',
      version='0.1.15',
      description='This package contains some modules used by different Findex projects.',
      url='http://github.com/skftn/findex-gui',
      author='Sander Ferdinand',
      author_email='sanderf@cedsys.nl',
      license='MIT',
      packages=['findex_common'],
      zip_safe=False)
